Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(217)

Unified Diff: src/full-codegen.h

Issue 16801006: Allocate generator result objects before unwinding try handlers (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Switch fallthrough for yield boxing Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/arm/full-codegen-arm.cc ('k') | src/full-codegen.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/full-codegen.h
diff --git a/src/full-codegen.h b/src/full-codegen.h
index 68263a5dc611dc71d46872275728e5f15f1945d6..6d84ef15ecf0145988051754f11a7ae14cedf8cb 100644
--- a/src/full-codegen.h
+++ b/src/full-codegen.h
@@ -410,10 +410,10 @@ class FullCodeGenerator: public AstVisitor {
// this has to be a separate pass _before_ populating or executing any module.
void AllocateModules(ZoneList<Declaration*>* declarations);
- // Generator code to return a fresh iterator result object. The "value"
- // property is set to a value popped from the stack, and "done" is set
- // according to the argument.
- void EmitReturnIteratorResult(bool done);
+ // Generate code to create an iterator result object. The "value" property is
+ // set to a value popped from the stack, and "done" is set according to the
+ // argument. The result object is left in the result register.
+ void EmitCreateIteratorResult(bool done);
// Try to perform a comparison as a fast inlined literal compare if
// the operands allow it. Returns true if the compare operations
@@ -472,6 +472,11 @@ class FullCodeGenerator: public AstVisitor {
void EmitProfilingCounterDecrement(int delta);
void EmitProfilingCounterReset();
+ // Emit code to pop values from the stack associated with nested statements
+ // like try/catch, try/finally, etc, running the finallies and unwinding the
+ // handlers as needed.
+ void EmitUnwindBeforeReturn();
+
// Platform-specific return sequence
void EmitReturnSequence();
« no previous file with comments | « src/arm/full-codegen-arm.cc ('k') | src/full-codegen.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698